#[repr(i32)]pub enum OrchestratorOption {
Unspecified = 0,
UseOrchestrator = 1,
DoNotUseOrchestrator = 2,
}Expand description
Specifies how to execute the test.
Variants
Unspecified = 0
Default value: the server will choose the mode. Currently implies that the test will run without the orchestrator. In the future, all instrumentation tests will be run with the orchestrator. Using the orchestrator is highly encouraged because of all the benefits it offers.
UseOrchestrator = 1
Run test using orchestrator. ** Only compatible with AndroidJUnitRunner version 1.1 or higher! ** Recommended.
DoNotUseOrchestrator = 2
Run test without using orchestrator.
Implementations
Sourceimpl OrchestratorOption
impl OrchestratorOption
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.