#[repr(i32)]pub enum OutcomeSummary {
Unspecified = 0,
Success = 1,
Failure = 2,
Inconclusive = 3,
Skipped = 4,
}Expand description
Outcome summary for a finished test matrix.
Variants
Unspecified = 0
Do not use. For proto versioning only.
Success = 1
The test matrix run was successful, for instance:
- All the test cases passed.
- Robo did not detect a crash of the application under test.
Failure = 2
A run failed, for instance:
- One or more test cases failed.
- A test timed out.
- The application under test crashed.
Inconclusive = 3
Something unexpected happened. The run should still be considered unsuccessful but this is likely a transient problem and re-running the test might be successful.
Skipped = 4
All tests were skipped, for instance:
- All device configurations were incompatible.
Implementations
Sourceimpl OutcomeSummary
impl OutcomeSummary
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.