#[repr(i32)]pub enum RoboMode {
Unspecified = 0,
RoboVersion1 = 1,
RoboVersion2 = 2,
}Expand description
The mode in which Robo should run.
Variants
Unspecified = 0
This means that the server should choose the mode. Recommended.
RoboVersion1 = 1
Runs Robo in UIAutomator-only mode without app resigning
RoboVersion2 = 2
Runs Robo in standard Espresso with UIAutomator fallback
Implementations
Sourceimpl RoboMode
impl RoboMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.