pub enum Environment {
AndroidDevice(AndroidDevice),
IosDevice(IosDevice),
}Expand description
Required. The environment.
Variants
AndroidDevice(AndroidDevice)
An Android device which must be used with an Android test.
IosDevice(IosDevice)
An iOS device which must be used with an iOS test.
Implementations
Sourceimpl Environment
impl Environment
Sourcepub fn merge(
field: &mut Option<Environment>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Environment>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.