AndroidModel

pub struct AndroidModel {
Show 18 fields pub id: String, pub name: String, pub manufacturer: String, pub brand: String, pub codename: String, pub form: i32, pub form_factor: i32, pub per_version_info: Vec<PerAndroidVersionInfo>, pub screen_x: i32, pub screen_y: i32, pub screen_density: i32, pub low_fps_video_recording: bool, pub supported_version_ids: Vec<String>, pub supported_abis: Vec<String>, pub tags: Vec<String>, pub thumbnail_url: String, pub lab_info: Option<LabInfo>, pub access_denied_reasons: Vec<i32>,
}
A description of an Android device tests may be run on.

Fields

id: String

The unique opaque id for this model. Use this for invoking the TestExecutionService.

name: String

The human-readable marketing name for this device model. Examples: “Nexus 5”, “Galaxy S5”.

manufacturer: String

The manufacturer of this device.

brand: String

The company that this device is branded with. Example: “Google”, “Samsung”.

codename: String

The name of the industrial design. This corresponds to android.os.Build.DEVICE.

form: i32

Whether this device is virtual or physical.

form_factor: i32

Whether this device is a phone, tablet, wearable, etc.

per_version_info: Vec<PerAndroidVersionInfo>

Version-specific information of an Android model.

screen_x: i32

Screen size in the horizontal (X) dimension measured in pixels.

screen_y: i32

Screen size in the vertical (Y) dimension measured in pixels.

screen_density: i32

Screen density in DPI. This corresponds to ro.sf.lcd_density

low_fps_video_recording: bool

True if and only if tests with this model are recorded by stitching together screenshots. See use_low_spec_video_recording in device config.

supported_version_ids: Vec<String>

The set of Android versions this device supports.

supported_abis: Vec<String>

The list of supported ABIs for this device. This corresponds to either android.os.Build.SUPPORTED_ABIS (for API level 21 and above) or android.os.Build.CPU_ABI/CPU_ABI2. The most preferred ABI is the first element in the list.

Elements are optionally prefixed by “version_id:” (where version_id is the id of an AndroidVersion), denoting an ABI that is supported only on a particular version.

tags: Vec<String>

Tags for this dimension. Examples: “default”, “preview”, “deprecated”.

thumbnail_url: String

URL of a thumbnail image (photo) of the device.

lab_info: Option<LabInfo>

Output only. Lab info of this device.

access_denied_reasons: Vec<i32>

Reasons for access denial. This model is accessible if this list is empty, otherwise the model is viewable only.

Implementations

Source

impl AndroidModel

pub fn form(&self) -> DeviceForm

Returns the enum value of form, or the default if the field is set to an invalid enum value.

pub fn set_form(&mut self, value: DeviceForm)

Sets form to the provided enum value.

pub fn form_factor(&self) -> DeviceFormFactor

Returns the enum value of form_factor, or the default if the field is set to an invalid enum value.

pub fn set_form_factor(&mut self, value: DeviceFormFactor)

Sets form_factor to the provided enum value.

pub fn access_denied_reasons( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<AccessDeniedReason>>

Returns an iterator which yields the valid enum values contained in access_denied_reasons.

pub fn push_access_denied_reasons(&mut self, value: AccessDeniedReason)

Appends the provided enum value to access_denied_reasons.