AndroidTestLoop

pub struct AndroidTestLoop {
    pub app_package_id: String,
    pub scenarios: Vec<i32>,
    pub scenario_labels: Vec<String>,
    pub app_under_test: Option<AppUnderTest>,
}
A test of an Android Application with a Test Loop. The intent <intent-name> will be implicitly added, since Games is the only user of this api, for the time being.

Fields

app_package_id: String

The java package for the application under test. The default is determined by examining the application’s manifest.

scenarios: Vec<i32>

The list of scenarios that should be run during the test. The default is all test loops, derived from the application’s manifest.

scenario_labels: Vec<String>

The list of scenario labels that should be run during the test. The scenario labels should map to labels defined in the application’s manifest. For example, player_experience and com.google.test.loops.player_experience add all of the loops labeled in the manifest with the com.google.test.loops.player_experience name to the execution. Scenarios can also be specified in the scenarios field.

app_under_test: Option<AppUnderTest>

Required. The Android package to test.