IosModel

pub struct IosModel {
    pub id: String,
    pub name: String,
    pub supported_version_ids: Vec<String>,
    pub tags: Vec<String>,
    pub device_capabilities: Vec<String>,
    pub screen_x: i32,
    pub screen_y: i32,
    pub screen_density: i32,
    pub form_factor: i32,
    pub per_version_info: Vec<PerIosVersionInfo>,
}
A description of an iOS device tests may be run on.

Fields

id: String

The unique opaque id for this model. Use this for invoking the TestExecutionService.

name: String

The human-readable name for this device model. Examples: “iPhone 4s”, “iPad Mini 2”.

supported_version_ids: Vec<String>

The set of iOS major software versions this device supports.

tags: Vec<String>

Tags for this dimension. Examples: “default”, “preview”, “deprecated”.

device_capabilities: Vec<String>screen_x: i32

Screen size in the horizontal (X) dimension measured in pixels.

screen_y: i32

Screen size in the vertical (Y) dimension measured in pixels.

screen_density: i32

Screen density in DPI.

form_factor: i32

Whether this device is a phone, tablet, wearable, etc.

per_version_info: Vec<PerIosVersionInfo>

Version-specific information of an iOS model.

Implementations

Source

impl IosModel

pub fn form_factor(&self) -> DeviceFormFactor

Returns the enum value of form_factor, or the default if the field is set to an invalid enum value.

pub fn set_form_factor(&mut self, value: DeviceFormFactor)

Sets form_factor to the provided enum value.