IosXcTest

pub struct IosXcTest {
    pub tests_zip: Option<FileReference>,
    pub xctestrun: Option<FileReference>,
    pub xcode_version: String,
    pub app_bundle_id: String,
    pub test_special_entitlements: bool,
}
A test of an iOS application that uses the XCTest framework. Xcode supports the option to “build for testing”, which generates an .xctestrun file that contains a test specification (arguments, test methods, etc). This test type accepts a zip file containing the .xctestrun file and the corresponding contents of the Build/Products directory that contains all the binaries needed to run the tests.

Fields

tests_zip: Option<FileReference>

Required. The .zip containing the .xctestrun file and the contents of the DerivedData/Build/Products directory. The .xctestrun file in this zip is ignored if the xctestrun field is specified.

xctestrun: Option<FileReference>

An .xctestrun file that will override the .xctestrun file in the tests zip. Because the .xctestrun file contains environment variables along with test methods to run and/or ignore, this can be useful for sharding tests. Default is taken from the tests zip.

xcode_version: String

The Xcode version that should be used for the test. Use the TestEnvironmentDiscoveryService to get supported options. Defaults to the latest Xcode version Firebase Test Lab supports.

app_bundle_id: String

Output only. The bundle id for the application under test.

test_special_entitlements: bool

The option to test special app entitlements. Setting this would re-sign the app having special entitlements with an explicit application-identifier. Currently supports testing aps-environment entitlement.