RoboDirective

pub struct RoboDirective {
    pub resource_name: String,
    pub input_text: String,
    pub action_type: i32,
}
Directs Robo to interact with a specific UI element if it is encountered during the crawl. Currently, Robo can perform text entry or element click.

Fields

resource_name: String

Required. The android resource name of the target UI element. For example, in Java: R.string.foo in xml: @string/foo Only the “foo” part is needed. Reference doc: https://developer.android.com/guide/topics/resources/accessing-resources.html

input_text: String

The text that Robo is directed to set. If left empty, the directive will be treated as a CLICK on the element matching the resource_name.

action_type: i32

Required. The type of action that Robo should perform on the specified element.

Implementations

Source

impl RoboDirective

pub fn action_type(&self) -> RoboActionType

Returns the enum value of action_type, or the default if the field is set to an invalid enum value.

pub fn set_action_type(&mut self, value: RoboActionType)

Sets action_type to the provided enum value.